=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2009-05-22 22:29:54 +0000
+++ drizzled/db.cc	2009-05-27 23:03:42 +0000
@@ -127,8 +127,7 @@
   if (!dbcache_init)
   {
     dbcache_init= true;
-    error= hash_init(&lock_db_cache, lower_case_table_names ?
-                     &my_charset_bin : system_charset_info,
+    error= hash_init(&lock_db_cache, &my_charset_bin,
                      32, 0, 0, (hash_get_key) lock_db_get_key,
                      lock_db_free_element,0);
 
@@ -246,13 +245,15 @@
 int load_db_opt_by_name(const char *db_name, HA_CREATE_INFO *db_create_info)
 {
   char db_opt_path[FN_REFLEN];
+  size_t length;
 
   /*
     Pass an empty file name, and the database options file name as extension
     to avoid table name to file name encoding.
   */
-  (void) build_table_filename(db_opt_path, sizeof(db_opt_path),
-                              db_name, "", MY_DB_OPT_FILE, 0);
+  length= build_table_filename(db_opt_path, sizeof(db_opt_path),
+                              db_name, "", false);
+  strcpy(db_opt_path + length, MY_DB_OPT_FILE);
 
   return load_db_opt(db_opt_path, db_create_info);
 }
@@ -267,14 +268,11 @@
   db		Name of database to create
 		Function assumes that this is already validated.
   create_info	Database create options (like character set)
-  silent	Used by replication when internally creating a database.
-		In this case the entry should not be logged.
 
   SIDE-EFFECTS
    1. Report back to client that command succeeded (my_ok)
    2. Report errors to client
    3. Log event to binary log
-   (The 'silent' flags turns off 1 and 3.)
 
   RETURN VALUES
   false ok
@@ -282,12 +280,12 @@
 
 */
 
-int mysql_create_db(Session *session, char *db, HA_CREATE_INFO *create_info, bool silent)
+bool mysql_create_db(Session *session, const char *db, HA_CREATE_INFO *create_info)
 {
   char	 path[FN_REFLEN+16];
-  char	 tmp_query[FN_REFLEN+16];
   long result= 1;
-  int error= 0;
+  int error_erno;
+  bool error= false;
   uint32_t create_options= create_info ? create_info->options : 0;
   uint32_t path_len;
 
@@ -312,14 +310,14 @@
   */
   if (wait_if_global_read_lock(session, 0, 1))
   {
-    error= -1;
+    error= true;
     goto exit2;
   }
 
   pthread_mutex_lock(&LOCK_create_db);
 
   /* Check directory */
-  path_len= build_table_filename(path, sizeof(path), db, "", "", 0);
+  path_len= build_table_filename(path, sizeof(path), db, "", false);
   path[path_len-1]= 0;                    // Remove last '/' from path
 
   if (mkdir(path,0777) == -1)
@@ -329,57 +327,41 @@
       if (!(create_options & HA_LEX_CREATE_IF_NOT_EXISTS))
       {
 	my_error(ER_DB_CREATE_EXISTS, MYF(0), db);
-	error= -1;
+	error= true;
 	goto exit;
       }
       push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
 			  ER_DB_CREATE_EXISTS, ER(ER_DB_CREATE_EXISTS), db);
-      if (!silent)
-	session->my_ok();
-      error= 0;
+      session->my_ok();
+      error= false;
       goto exit;
     }
 
     my_error(ER_CANT_CREATE_DB, MYF(0), db, my_errno);
-    error= -1;
+    error= true;
     goto exit;
   }
 
-  error= write_schema_file(session, path, db, create_info);
-  if (error && error != EEXIST)
+  error_erno= write_schema_file(session, path, db, create_info);
+  if (error_erno && error_erno != EEXIST)
   {
     if (rmdir(path) >= 0)
     {
-      error= -1;
+      error= true;
       goto exit;
     }
   }
-
-  if (!silent)
-  {
-    char *query;
-    uint32_t query_length;
-
-    if (!session->query)				// Only in replication
-    {
-      query= tmp_query;
-      query_length= sprintf(tmp_query, "create database `%s`", db);
-    }
-    else
-    {
-      query= 	    session->query;
-      query_length= session->query_length;
-    }
-
-    transaction_services.rawStatement(session, query, query_length);
-    session->my_ok(result);
-  }
+  else if (error_erno)
+    error= true;
+
+  transaction_services.rawStatement(session, session->query, session->query_length);
+  session->my_ok(result);
 
 exit:
   pthread_mutex_unlock(&LOCK_create_db);
   start_waiting_global_read_lock(session);
 exit2:
-  return(error);
+  return error;
 }
 
 
@@ -410,7 +392,7 @@
   pthread_mutex_lock(&LOCK_create_db);
 
   /* Change options if current database is being altered. */
-  path_len= build_table_filename(path, sizeof(path), db, "", "", 0);
+  path_len= build_table_filename(path, sizeof(path), db, "", false);
   path[path_len-1]= 0;                    // Remove last '/' from path
 
   error= write_schema_file(session, path, db, create_info);
@@ -427,7 +409,7 @@
   pthread_mutex_unlock(&LOCK_create_db);
   start_waiting_global_read_lock(session);
 exit:
-  return(error);
+  return error ? true : false;
 }
 
 
@@ -448,7 +430,7 @@
     ERROR Error
 */
 
-bool mysql_rm_db(Session *session,char *db,bool if_exists, bool silent)
+bool mysql_rm_db(Session *session,char *db,bool if_exists)
 {
   long deleted=0;
   int error= false;
@@ -483,7 +465,7 @@
 
   pthread_mutex_lock(&LOCK_create_db);
 
-  length= build_table_filename(path, sizeof(path), db, "", "", 0);
+  length= build_table_filename(path, sizeof(path), db, "", false);
   strcpy(path+length, MY_DB_OPT_FILE);         // Append db option file name
   unlink(path);
   path[length]= '\0';				// Remove file name
@@ -515,7 +497,7 @@
       error = 0;
     }
   }
-  if (!silent && deleted>=0)
+  if (deleted >= 0)
   {
     const char *query;
     uint32_t query_length;
@@ -598,9 +580,9 @@
 				 const char *org_path,
                                  TableList **dropped_tables)
 {
-  long deleted=0;
+  long deleted= 0;
   char filePath[FN_REFLEN];
-  TableList *tot_list=0, **tot_list_next;
+  TableList *tot_list= NULL, **tot_list_next;
 
   tot_list_next= &tot_list;
 
@@ -641,7 +623,7 @@
       uint32_t db_len= strlen(db);
 
       /* Drop the table nicely */
-      *extension= 0;			// Remove extension
+      *extension= NULL;			// Remove extension
       TableList *table_list=(TableList*)
                               session->calloc(sizeof(*table_list) +
                                           db_len + 1 +
@@ -682,7 +664,7 @@
   if (rm_dir_w_symlink(org_path))
     return -1;
 
-  return(deleted);
+  return deleted;
 
 err:
   my_dirend(dirp);
@@ -1092,7 +1074,7 @@
   uint32_t db_dir_path_len;
 
   db_dir_path_len= build_table_filename(db_dir_path, sizeof(db_dir_path),
-                                        db_name, "", "", 0);
+                                        db_name, "", false);
 
   if (db_dir_path_len && db_dir_path[db_dir_path_len - 1] == FN_LIBCHAR)
     db_dir_path[db_dir_path_len - 1]= 0;

=== modified file 'drizzled/db.h'
--- drizzled/db.h	2009-05-14 08:35:31 +0000
+++ drizzled/db.h	2009-05-27 18:47:48 +0000
@@ -21,9 +21,9 @@
 #ifndef DRIZZLE_SERVER_DB_H
 #define DRIZZLE_SERVER_DB_H
 
-int mysql_create_db(Session *session, char *db, HA_CREATE_INFO *create, bool silent);
+bool mysql_create_db(Session *session, const char *db, HA_CREATE_INFO *create_info);
 bool mysql_alter_db(Session *session, const char *db, HA_CREATE_INFO *create);
-bool mysql_rm_db(Session *session,char *db,bool if_exists, bool silent);
+bool mysql_rm_db(Session *session,char *db, bool if_exists);
 bool mysql_change_db(Session *session, const LEX_STRING *new_db_name,
                      bool force_switch);
 bool mysql_opt_change_db(Session *session,

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2009-05-26 02:54:31 +0000
+++ drizzled/drizzled.cc	2009-05-27 21:11:30 +0000
@@ -278,7 +278,6 @@
 uint32_t drizzled_port, test_flags, select_errors, dropping_tables, ha_open_options;
 uint32_t drizzled_port_timeout;
 uint32_t delay_key_write_options, protocol_version= PROTOCOL_VERSION;
-uint32_t lower_case_table_names= 1;
 uint32_t tc_heuristic_recover= 0;
 uint64_t session_startup_options;
 uint32_t back_log;
@@ -1493,8 +1492,7 @@
   }
   global_system_variables.lc_time_names= my_default_lc_time_names;
 
-  /* Reset table_alias_charset, now that lower_case_table_names is set. */
-  lower_case_table_names= 1; /* This we need to look at */
+  /* Reset table_alias_charset */
   table_alias_charset= files_charset_info;
 
   return 0;

=== modified file 'drizzled/handler.cc'
--- drizzled/handler.cc	2009-05-26 02:54:31 +0000
+++ drizzled/handler.cc	2009-05-27 21:11:30 +0000
@@ -3615,15 +3615,3 @@
 
   return 0;
 }
-
-void table_case_convert(char * name, uint32_t length)
-{
-  if (lower_case_table_names)
-    files_charset_info->cset->casedn(files_charset_info,
-                                     name, length, name, length);
-}
-
-const char *table_case_name(HA_CREATE_INFO *info, const char *name)
-{
-  return ((lower_case_table_names == 2 && info->alias) ? info->alias : name);
-}

=== modified file 'drizzled/handler.h'
--- drizzled/handler.h	2009-05-26 02:54:31 +0000
+++ drizzled/handler.h	2009-05-27 21:11:30 +0000
@@ -1021,10 +1021,6 @@
 /* these are called by storage engines */
 void trans_register_ha(Session *session, bool all, StorageEngine *engine);
 
-void table_case_convert(char * name, uint32_t length);
-const char *table_case_name(HA_CREATE_INFO *info, const char *name);
-
-extern uint32_t lower_case_table_names;
 uint32_t filename_to_tablename(const char *from, char *to, uint32_t to_length);
 uint32_t tablename_to_filename(const char *from, char *to, uint32_t to_length);
 

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2009-05-22 18:03:52 +0000
+++ drizzled/item.cc	2009-05-27 21:11:30 +0000
@@ -1086,7 +1086,7 @@
   else
     return NULL;
 
-  if (db_name && lower_case_table_names)
+  if (db_name)
   {
     /* Convert database to lower case for comparison */
     strncpy(name_buff, db_name, sizeof(name_buff)-1);

=== modified file 'drizzled/item/ident.cc'
--- drizzled/item/ident.cc	2009-02-21 00:18:15 +0000
+++ drizzled/item/ident.cc	2009-05-27 21:11:30 +0000
@@ -119,19 +119,15 @@
   if (table_name && table_name[0])
   {
     t_name.assign(table_name);
-    if (lower_case_table_names== 1 ||
-        (lower_case_table_names == 2 && !alias_name_used))
-      // Keeping the std:: here, since Item_ident has a transform method
-      std::transform(t_name.begin(), t_name.end(),
-                     t_name.begin(), ::tolower);
+    std::transform(t_name.begin(), t_name.end(),
+                   t_name.begin(), ::tolower);
   }
  
   if (db_name && db_name[0])
   {
     d_name.assign(db_name);
-    if (lower_case_table_names== 1 ||
-        (lower_case_table_names == 2 && !alias_name_used))
-      // Keeping the std:: prefix here, since Item_ident has a transform method
+    // Keeping the std:: prefix here, since Item_ident has a transform
+    // method
       std::transform(d_name.begin(), d_name.end(),
                      d_name.begin(), ::tolower);
   }

=== modified file 'drizzled/plugin/storage_engine.cc'
--- drizzled/plugin/storage_engine.cc	2009-04-29 00:32:11 +0000
+++ drizzled/plugin/storage_engine.cc	2009-05-27 23:37:50 +0000
@@ -437,6 +437,7 @@
                               StorageEngine **engine_arg)
 {
   StorageEngine *engine= NULL;
+  bool found= false;
 
   drizzled::Registry<StorageEngine *>::iterator iter=
     find_if(all_engines.begin(), all_engines.end(),
@@ -444,20 +445,25 @@
   if (iter != all_engines.end()) 
   {
     engine= *iter;
+    found= true;
   }
   else
   {
     /* Default way of knowing if a table exists. (checking .frm exists) */
 
     char path[FN_REFLEN];
-    build_table_filename(path, sizeof(path),
-                         db, name, "", 0);
-    if (table_proto_exists(path)==EEXIST)
+    size_t length;
+    length= build_table_filename(path, sizeof(path),
+                                 db, name, false);
+
+    if ((table_proto_exists(path) == EEXIST))
+      found= true;
+
+    if (found && engine_arg)
     {
       drizzled::message::Table table;
-      build_table_filename(path, sizeof(path),
-                           db, name, ".dfe", 0);
-      if(drizzle_read_table_proto(path, &table)==0)
+      strcpy(path + length, ".dfe");
+      if (drizzle_read_table_proto(path, &table) == 0)
       {
         LEX_STRING engine_name= { (char*)table.engine().name().c_str(),
                                  strlen(table.engine().name().c_str()) };
@@ -466,11 +472,12 @@
     }
   }
 
-  if(engine_arg)
+  if (found == false)
+    return HA_ERR_NO_SUCH_TABLE;
+
+  if (engine_arg)
     *engine_arg= engine;
 
-  if (engine == NULL)
-    return HA_ERR_NO_SUCH_TABLE;
   return HA_ERR_TABLE_EXIST;
 }
 
@@ -478,7 +485,7 @@
 static const char *check_lowercase_names(handler *file, const char *path,
                                          char *tmp_path)
 {
-  if (lower_case_table_names != 2 || (file->ha_table_flags() & HA_FILE_BASED))
+  if ((file->ha_table_flags() & HA_FILE_BASED))
     return path;
 
   /* Ensure that table handler get path in lower case */

=== modified file 'drizzled/plugin/storage_engine.h'
--- drizzled/plugin/storage_engine.h	2009-05-21 00:57:05 +0000
+++ drizzled/plugin/storage_engine.h	2009-05-26 20:57:34 +0000
@@ -49,8 +49,6 @@
   HTON_BIT_FLUSH_AFTER_RENAME,
   HTON_BIT_NOT_USER_SELECTABLE,
   HTON_BIT_TEMPORARY_NOT_SUPPORTED,   // Having temporary tables not supported
-  HTON_BIT_SUPPORT_LOG_TABLES,        // Engine supports log tables
-  HTON_BIT_NO_PARTITION,              // You can not partition these tables
   HTON_BIT_SIZE
 };
 
@@ -62,8 +60,6 @@
 static const std::bitset<HTON_BIT_SIZE> HTON_FLUSH_AFTER_RENAME(1 << HTON_BIT_FLUSH_AFTER_RENAME);
 static const std::bitset<HTON_BIT_SIZE> HTON_NOT_USER_SELECTABLE(1 << HTON_BIT_NOT_USER_SELECTABLE);
 static const std::bitset<HTON_BIT_SIZE> HTON_TEMPORARY_NOT_SUPPORTED(1 << HTON_BIT_TEMPORARY_NOT_SUPPORTED);
-static const std::bitset<HTON_BIT_SIZE> HTON_SUPPORT_LOG_TABLES(1 << HTON_BIT_SUPPORT_LOG_TABLES);
-static const std::bitset<HTON_BIT_SIZE> HTON_NO_PARTITION(1 << HTON_BIT_NO_PARTITION);
 
 /*
   StorageEngine is a singleton structure - one instance per storage engine -

=== modified file 'drizzled/rename.cc'
--- drizzled/rename.cc	2009-05-23 00:00:59 +0000
+++ drizzled/rename.cc	2009-05-27 23:37:50 +0000
@@ -31,7 +31,7 @@
   Every second entry in the table_list is the original name and every
   second entry is the new name.
 */
-bool drizzle_rename_tables(Session *session, TableList *table_list, bool silent)
+bool drizzle_rename_tables(Session *session, TableList *table_list)
 {
   bool error= true;
   TableList *ren_table= NULL;
@@ -56,7 +56,7 @@
     goto err;
   }
 
-  error=0;
+  error= false;
   if ((ren_table=rename_tables(session,table_list,0)))
   {
     /* Rename didn't succeed;  rename back the tables in reverse order */
@@ -76,7 +76,7 @@
     /* Revert the table list (for prepared statements) */
     table_list= reverse_table_list(table_list);
 
-    error= 1;
+    error= true;
   }
   /*
     An exclusive lock on table names is satisfactory to ensure
@@ -88,7 +88,7 @@
   pthread_mutex_unlock(&LOCK_open);
 
   /* Lets hope this doesn't fail as the result will be messy */
-  if (!silent && !error)
+  if (!error)
   {
     write_bin_log(session, true, session->query, session->query_length);
     session->my_ok();
@@ -100,7 +100,7 @@
 
 err:
   start_waiting_global_read_lock(session);
-  return(error);
+  return error;
 }
 
 
@@ -138,7 +138,6 @@
       ren_table         A table/view to be renamed
       new_db            The database to which the table to be moved to
       new_table_name    The new table/view name
-      new_table_alias   The new table/view alias
       skip_error        Whether to skip error
 
   DESCRIPTION
@@ -149,19 +148,12 @@
     true      rename failed
 */
 
-bool
-do_rename(Session *session, TableList *ren_table, char *new_db, char *new_table_name,
-          char *new_table_alias, bool skip_error)
+static bool
+do_rename(Session *session, TableList *ren_table, const char *new_db, const char *new_table_name, bool skip_error)
 {
-  int rc= 1;
+  bool rc= true;
   const char *new_alias, *old_alias;
 
-  if (lower_case_table_names == 2)
-  {
-    old_alias= ren_table->alias;
-    new_alias= new_table_alias;
-  }
-  else
   {
     old_alias= ren_table->table_name;
     new_alias= new_table_name;
@@ -169,11 +161,11 @@
 
   StorageEngine *engine= NULL;
 
-  if(ha_table_exists_in_engine(session, ren_table->db, old_alias, &engine)
+  if (ha_table_exists_in_engine(session, ren_table->db, old_alias, &engine)
      != HA_ERR_TABLE_EXIST)
   {
     my_error(ER_NO_SUCH_TABLE, MYF(0), ren_table->db, old_alias);
-    return(1);
+    return true;
   }
 
   if (ha_table_exists_in_engine(session, new_db, new_alias)
@@ -187,9 +179,9 @@
                          ren_table->db, old_alias,
                          new_db, new_alias, 0);
   if (rc && !skip_error)
-    return(1);
+    return true;
 
-  return(0);
+  return false;
 
 }
 /*
@@ -224,8 +216,7 @@
   for (ren_table= table_list; ren_table; ren_table= new_table->next_local)
   {
     new_table= ren_table->next_local;
-    if (do_rename(session, ren_table, new_table->db, new_table->table_name,
-                  new_table->alias, skip_error))
+    if (do_rename(session, ren_table, new_table->db, new_table->table_name, skip_error))
       return(ren_table);
   }
   return(0);

=== modified file 'drizzled/rename.h'
--- drizzled/rename.h	2009-01-05 07:47:52 +0000
+++ drizzled/rename.h	2009-05-27 21:11:30 +0000
@@ -21,6 +21,6 @@
 #ifndef DRIZZLED_RENAME_H
 #define DRIZZLED_RENAME_H
 
-bool drizzle_rename_tables(Session *session, TableList *table_list, bool silent);
+bool drizzle_rename_tables(Session *session, TableList *table_list);
 
 #endif /* DRIZZLED_RENAME_H */

=== modified file 'drizzled/server_includes.h'
--- drizzled/server_includes.h	2009-05-23 00:05:52 +0000
+++ drizzled/server_includes.h	2009-05-27 23:03:42 +0000
@@ -260,8 +260,8 @@
 char *fn_rext(char *name);
 
 /* Conversion functions */
-uint32_t build_table_filename(char *buff, size_t bufflen, const char *db,
-                          const char *table, const char *ext, uint32_t flags);
+size_t build_table_filename(char *buff, size_t bufflen, const char *db, 
+                            const char *table_name, bool is_tmp);
 
 /* Flags for conversion functions. */
 #define FN_FROM_IS_TMP  (1 << 0)

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2009-05-26 02:54:31 +0000
+++ drizzled/show.cc	2009-05-27 23:03:42 +0000
@@ -322,12 +322,7 @@
       file_name_len= filename_to_tablename(file->name, uname, sizeof(uname));
       if (wild)
       {
-        if (lower_case_table_names)
-        {
-          if (wild_case_compare(files_charset_info, uname, wild))
-            continue;
-        }
-        else if (wild_compare(uname, wild, 0))
+        if (wild_case_compare(files_charset_info, uname, wild))
           continue;
       }
     }
@@ -620,12 +615,8 @@
   if (table_list->schema_table)
     alias= table_list->schema_table->table_name;
   else
-  {
-    if (lower_case_table_names == 2)
-      alias= table->alias;
-    else
-      alias= share->table_name.str;
-  }
+    alias= share->table_name.str;
+
   packet->append_identifier(alias, strlen(alias));
   packet->append(STRING_WITH_LEN(" (\n"));
   /*
@@ -1994,14 +1985,9 @@
         return(0);
     if (wild)
     {
-      if (lower_case_table_names)
-      {
-        if (wild_case_compare(files_charset_info,
-                              schema_table->table_name,
-                              wild))
-          return(0);
-      }
-      else if (wild_compare(schema_table->table_name, wild, 0))
+      if (wild_case_compare(files_charset_info,
+                            schema_table->table_name,
+                            wild))
         return(0);
     }
   
@@ -2027,14 +2013,9 @@
       continue;
     if (wild)
     {
-      if (lower_case_table_names)
-      {
-        if (wild_case_compare(files_charset_info,
-                              tmp_schema_table->table_name,
-                              wild))
-          continue;
-      }
-      else if (wild_compare(tmp_schema_table->table_name, wild, 0))
+      if (wild_case_compare(files_charset_info,
+                            tmp_schema_table->table_name,
+                            wild))
         continue;
     }
     if ((file_name=
@@ -2081,7 +2062,7 @@
                      bool with_i_schema, LEX_STRING *db_name)
 {
   char path[FN_REFLEN];
-  build_table_filename(path, sizeof(path), db_name->str, "", "", 0);
+  build_table_filename(path, sizeof(path), db_name->str, "", false);
   if (!lookup_field_vals->wild_table_value &&
       lookup_field_vals->table_value.str)
   {
@@ -2233,7 +2214,7 @@
   {
     char path[FN_REFLEN];
     (void) build_table_filename(path, sizeof(path), db_name->str,
-                                table_name->str, "", 0);
+                                table_name->str, false);
 
       table->field[3]->store(STRING_WITH_LEN("BASE Table"),
                              system_charset_info);
@@ -2641,7 +2622,7 @@
     if (!lookup_field_vals.db_value.str[0])
       return(0);
     path_len= build_table_filename(path, sizeof(path),
-                                   lookup_field_vals.db_value.str, "", "", 0);
+                                   lookup_field_vals.db_value.str, "", false);
     path[path_len-1]= 0;
     if (stat(path,&stat_info))
       return(0);

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2009-05-26 02:54:31 +0000
+++ drizzled/sql_base.cc	2009-05-27 23:37:50 +0000
@@ -1204,9 +1204,7 @@
     if (((! (res= find_table_in_global_list(table_list, d_name, t_name))) &&
          (! (res= mysql_lock_have_duplicate(session, table, table_list)))) ||
         ((!res->table || res->table != table->table) &&
-         (!check_alias || !(lower_case_table_names ?
-          my_strcasecmp(files_charset_info, t_alias, res->alias) :
-          strcmp(t_alias, res->alias))) &&
+         (!check_alias || !(my_strcasecmp(files_charset_info, t_alias, res->alias))) &&
          res->select_lex && !res->select_lex->exclude_from_table_unique_test))
       break;
     /*
@@ -1824,7 +1822,7 @@
   register Table *table;
   char key[MAX_DBKEY_LENGTH];
   unsigned int key_length;
-  char *alias= table_list->alias;
+  const char *alias= table_list->alias;
   HASH_SEARCH_STATE state;
 
   /* Parsing of partitioning information from .frm needs session->lex set up. */
@@ -2123,9 +2121,9 @@
 
     if (table_list->create)
     {
-      if(ha_table_exists_in_engine(session, table_list->db,
+      if (ha_table_exists_in_engine(session, table_list->db,
                                    table_list->table_name)
-         != HA_ERR_TABLE_EXIST)
+          != HA_ERR_TABLE_EXIST)
       {
         /*
           Table to be created, so we need to create placeholder in table-cache.
@@ -4024,7 +4022,7 @@
     }
   }
 
-  if (db && lower_case_table_names)
+  if (db)
   {
     /*
       convert database to lower case for comparison.
@@ -5340,7 +5338,7 @@
   bool found;
   char name_buff[NAME_LEN+1];
 
-  if (db_name && lower_case_table_names)
+  if (db_name)
   {
     /*
       convert database to lower case for comparison

=== modified file 'drizzled/sql_delete.cc'
--- drizzled/sql_delete.cc	2009-05-23 00:00:59 +0000
+++ drizzled/sql_delete.cc	2009-05-27 23:03:42 +0000
@@ -820,7 +820,7 @@
   }
 
   path_length= build_table_filename(path, sizeof(path), table_list->db,
-                                    table_list->table_name, "", 0);
+                                    table_list->table_name, 0);
 
   if (!dont_send_ok)
     goto trunc_by_del;

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2009-05-19 05:11:22 +0000
+++ drizzled/sql_insert.cc	2009-05-27 21:11:30 +0000
@@ -1564,8 +1564,7 @@
         if (reopen_name_locked_table(session, create_table, false))
         {
           quick_rm_table(create_info->db_type, create_table->db,
-                         table_case_name(create_info, create_table->table_name),
-                         0);
+                         create_table->table_name, 0);
         }
         else
           table= create_table->table;

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2009-05-21 19:15:01 +0000
+++ drizzled/sql_parse.cc	2009-05-27 21:11:30 +0000
@@ -823,7 +823,7 @@
       new_list= table->next_local[0];
     }
 
-    if (! session->endActiveTransaction() || drizzle_rename_tables(session, first_table, 0))
+    if (! session->endActiveTransaction() || drizzle_rename_tables(session, first_table))
     {
       goto error;
     }
@@ -1251,8 +1251,7 @@
       my_error(ER_WRONG_DB_NAME, MYF(0), lex->name.str);
       break;
     }
-    res= mysql_create_db(session,(lower_case_table_names == 2 ? alias :
-                              lex->name.str), &create_info, 0);
+    res= mysql_create_db(session,(lex->name.str), &create_info);
     break;
   }
   case SQLCOM_DROP_DB:
@@ -1272,7 +1271,7 @@
       my_message(ER_LOCK_OR_ACTIVE_TRANSACTION, ER(ER_LOCK_OR_ACTIVE_TRANSACTION), MYF(0));
       goto error;
     }
-    res= mysql_rm_db(session, lex->name.str, lex->drop_if_exists, 0);
+    res= mysql_rm_db(session, lex->name.str, lex->drop_if_exists);
     break;
   }
   case SQLCOM_ALTER_DB:
@@ -1981,7 +1980,7 @@
 
   ptr->alias= alias_str;
   ptr->is_alias= alias ? true : false;
-  if (lower_case_table_names && table->table.length)
+  if (table->table.length)
     table->table.length= my_casedn_str(files_charset_info, table->table.str);
   ptr->table_name=table->table.str;
   ptr->table_name_length=table->table.length;

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2009-05-23 00:00:59 +0000
+++ drizzled/sql_select.cc	2009-05-27 21:11:30 +0000
@@ -16351,9 +16351,8 @@
         str->append(' ');
 
         string t_alias(alias);
-        if (lower_case_table_names== 1)
-          transform(t_alias.begin(), t_alias.end(),
-                    t_alias.begin(), ::tolower);
+        transform(t_alias.begin(), t_alias.end(),
+                  t_alias.begin(), ::tolower);
 
         str->append_identifier(t_alias.c_str(), t_alias.length());
       }

=== modified file 'drizzled/sql_select.h'
--- drizzled/sql_select.h	2009-04-25 06:33:32 +0000
+++ drizzled/sql_select.h	2009-05-27 19:47:42 +0000
@@ -662,7 +662,7 @@
 Table *create_tmp_table(Session *session,Tmp_Table_Param *param,List<Item> &fields,
 			order_st *group, bool distinct, bool save_sum_fields,
 			uint64_t select_options, ha_rows rows_limit,
-			char* alias);
+			const char* alias);
 void free_tmp_table(Session *session, Table *entry);
 void count_field_types(Select_Lex *select_lex, Tmp_Table_Param *param,
                        List<Item> &fields, bool reset_with_sum_func);

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2009-05-23 00:00:59 +0000
+++ drizzled/sql_table.cc	2009-05-27 23:03:42 +0000
@@ -190,15 +190,14 @@
     path length on success, 0 on failure
 */
 
-uint32_t build_table_filename(char *buff, size_t bufflen, const char *db,
-                          const char *table_name, const char *ext, uint32_t flags)
+size_t build_table_filename(char *buff, size_t bufflen, const char *db, const char *table_name, bool is_tmp)
 {
   string table_path;
   char dbbuff[FN_REFLEN];
   char tbbuff[FN_REFLEN];
   int rootdir_len= strlen(FN_ROOTDIR);
 
-  if (flags & FN_IS_TMP) // FN_FROM_IS_TMP | FN_TO_IS_TMP
+  if (is_tmp) // FN_FROM_IS_TMP | FN_TO_IS_TMP
     strncpy(tbbuff, table_name, sizeof(tbbuff));
   else
     tablename_to_filename(table_name, tbbuff, sizeof(tbbuff));
@@ -221,12 +220,12 @@
   table_path.clear();
 #endif
   table_path.append(tbbuff);
-  table_path.append(ext);
 
   if (bufflen < table_path.length())
     return 0;
 
   strcpy(buff, table_path.c_str());
+
   return table_path.length();
 }
 
@@ -260,8 +259,7 @@
   post_tmpdir_str << session->thread_id << session->tmp_table++;
   tmp= post_tmpdir_str.str();
 
-  if (lower_case_table_names)
-    transform(tmp.begin(), tmp.end(), tmp.begin(), ::tolower);
+  transform(tmp.begin(), tmp.end(), tmp.begin(), ::tolower);
 
   path_str << tmp;
 
@@ -389,7 +387,7 @@
                          bool drop_temporary, bool dont_log_query)
 {
   TableList *table;
-  char path[FN_REFLEN], *alias;
+  char path[FN_REFLEN];
   uint32_t path_length= 0;
   String wrong_tables;
   int error= 0;
@@ -495,11 +493,8 @@
         error= -1;
         goto err_with_placeholders;
       }
-      alias= (lower_case_table_names == 2) ? table->alias : table->table_name;
       /* remove .frm file and engine files */
-      path_length= build_table_filename(path, sizeof(path), db, alias, "",
-                                        table->internal_tmp_table ?
-                                        FN_IS_TMP : 0);
+      path_length= build_table_filename(path, sizeof(path), db, table->table_name, table->internal_tmp_table);
     }
     if (drop_temporary ||
         ((table_type == NULL && (table_proto_exists(path)!=EEXIST))))
@@ -626,20 +621,20 @@
       base                      The StorageEngine handle.
       db                        The database name.
       table_name                The table name.
-      flags                     flags for build_table_filename().
+      is_tmp                    If the table is temp.
 
   RETURN
     0           OK
     != 0        Error
 */
 
-bool quick_rm_table(StorageEngine *,const char *db,
-                    const char *table_name, uint32_t flags)
+bool quick_rm_table(StorageEngine *, const char *db,
+                    const char *table_name, bool is_tmp)
 {
   char path[FN_REFLEN];
   bool error= 0;
 
-  build_table_filename(path, sizeof(path), db, table_name, "", flags);
+  build_table_filename(path, sizeof(path), db, table_name, is_tmp);
 
   error= delete_table_proto_file(path);
 
@@ -1677,7 +1672,6 @@
 {
   char		path[FN_REFLEN];
   uint32_t          path_length;
-  const char	*alias;
   uint		db_options, key_count;
   KEY		*key_info_buffer;
   handler	*file;
@@ -1695,7 +1689,6 @@
   db_options= create_info->table_options;
   if (create_info->row_type == ROW_TYPE_DYNAMIC)
     db_options|=HA_OPTION_PACK_RECORD;
-  alias= table_case_name(create_info, table_name);
   if (!(file= get_new_handler((TableShare*) 0, session->mem_root,
                               create_info->db_type)))
   {
@@ -1722,14 +1715,13 @@
   {
  #ifdef FN_DEVCHAR
     /* check if the table name contains FN_DEVCHAR when defined */
-    if (strchr(alias, FN_DEVCHAR))
+    if (strchr(table_name, FN_DEVCHAR))
     {
-      my_error(ER_WRONG_TABLE_NAME, MYF(0), alias);
+      my_error(ER_WRONG_TABLE_NAME, MYF(0), table_name);
       return(true);
     }
 #endif
-    path_length= build_table_filename(path, sizeof(path), db, alias, "",
-                                      internal_tmp_table ? FN_IS_TMP : 0);
+    path_length= build_table_filename(path, sizeof(path), db, table_name, internal_tmp_table);
   }
 
   /* Check if table already exists */
@@ -1741,11 +1733,11 @@
       create_info->table_existed= 1;		// Mark that table existed
       push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                           ER_TABLE_EXISTS_ERROR, ER(ER_TABLE_EXISTS_ERROR),
-                          alias);
+                          table_name);
       error= 0;
       goto err;
     }
-    my_error(ER_TABLE_EXISTS_ERROR, MYF(0), alias);
+    my_error(ER_TABLE_EXISTS_ERROR, MYF(0), table_name);
     goto err;
   }
 
@@ -1768,7 +1760,7 @@
       Then she could create the table. This case is pretty obscure and
       therefore we don't introduce a new error message only for it.
     */
-    if (get_cached_table_share(db, alias))
+    if (get_cached_table_share(db, table_name))
     {
       my_error(ER_TABLE_EXISTS_ERROR, MYF(0), table_name);
       goto unlock_and_end;
@@ -1874,7 +1866,7 @@
   error= false;
   push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                       ER_TABLE_EXISTS_ERROR, ER(ER_TABLE_EXISTS_ERROR),
-                      alias);
+                      table_name);
   create_info->table_existed= 1;		// Mark that table existed
   goto unlock_and_end;
 }
@@ -2031,40 +2023,19 @@
                    const char *new_name, uint32_t flags)
 {
   Session *session= current_session;
-  char from[FN_REFLEN], to[FN_REFLEN], lc_from[FN_REFLEN], lc_to[FN_REFLEN];
+  char from[FN_REFLEN], to[FN_REFLEN];
   char *from_base= from, *to_base= to;
-  char tmp_name[NAME_LEN+1];
   handler *file;
   int error=0;
 
   file= (base == NULL ? 0 :
          get_new_handler((TableShare*) 0, session->mem_root, base));
 
-  build_table_filename(from, sizeof(from), old_db, old_name, "",
+  build_table_filename(from, sizeof(from), old_db, old_name,
                        flags & FN_FROM_IS_TMP);
-  build_table_filename(to, sizeof(to), new_db, new_name, "",
+  build_table_filename(to, sizeof(to), new_db, new_name,
                        flags & FN_TO_IS_TMP);
 
-  /*
-    If lower_case_table_names == 2 (case-preserving but case-insensitive
-    file system) and the storage is not HA_FILE_BASED, we need to provide
-    a lowercase file name, but we leave the .frm in mixed case.
-   */
-  if (lower_case_table_names == 2 && file &&
-      !(file->ha_table_flags() & HA_FILE_BASED))
-  {
-    strcpy(tmp_name, old_name);
-    my_casedn_str(files_charset_info, tmp_name);
-    build_table_filename(lc_from, sizeof(lc_from), old_db, tmp_name, "",
-                         flags & FN_FROM_IS_TMP);
-    from_base= lc_from;
-
-    strcpy(tmp_name, new_name);
-    my_casedn_str(files_charset_info, tmp_name);
-    build_table_filename(lc_to, sizeof(lc_to), new_db, tmp_name, "",
-                         flags & FN_TO_IS_TMP);
-    to_base= lc_to;
-  }
   if (!file || !(error=file->ha_rename_table(from_base, to_base)))
   {
     if(!(flags & NO_FRM_RENAME)
@@ -2903,7 +2874,7 @@
     if (!name_lock)
       goto table_exists;
     dst_path_length= build_table_filename(dst_path, sizeof(dst_path),
-                                          db, table_name, "", 0);
+                                          db, table_name, false);
     if (table_proto_exists(dst_path)==EEXIST)
       goto table_exists;
   }
@@ -3733,7 +3704,7 @@
     true   Error
 */
 
-bool mysql_alter_table(Session *session,char *new_db, char *new_name,
+bool mysql_alter_table(Session *session, char *new_db, char *new_name,
                        HA_CREATE_INFO *create_info,
                        TableList *table_list,
                        Alter_info *alter_info,
@@ -3743,7 +3714,8 @@
   string new_name_str;
   int error= 0;
   char tmp_name[80],old_name[32],new_name_buff[FN_REFLEN];
-  char new_alias_buff[FN_REFLEN], *table_name, *db, *new_alias, *alias;
+  char new_alias_buff[FN_REFLEN], *table_name, *db;
+  const char *new_alias;
   char path[FN_REFLEN];
   ha_rows copied= 0,deleted= 0;
   StorageEngine *old_db_type, *new_db_type, *save_old_db_type;
@@ -3762,12 +3734,11 @@
     later just by comparing the pointers, avoiding the need for strcmp.
   */
   session->set_proc_info("init");
-  table_name=table_list->table_name;
-  alias= (lower_case_table_names == 2) ? table_list->alias : table_name;
+  table_name= table_list->table_name;
   db=table_list->db;
   if (!new_db || !my_strcasecmp(table_alias_charset, new_db, db))
     new_db= db;
-  build_table_filename(path, sizeof(path), db, table_name, "", 0);
+  build_table_filename(path, sizeof(path), db, table_name, false);
 
   /* DISCARD/IMPORT TABLESPACE is always alone in an ALTER Table */
   if (alter_info->tablespace_op != NO_TABLESPACE_OP)
@@ -3799,17 +3770,14 @@
   /* Check that we are not trying to rename to an existing table */
   if (new_name)
   {
-    strcpy(new_name_buff,new_name);
-    strcpy(new_alias= new_alias_buff, new_name);
-    if (lower_case_table_names)
-    {
-      if (lower_case_table_names != 2)
-      {
-        my_casedn_str(files_charset_info, new_name_buff);
-        new_alias= new_name;			// Create lower case table name
-      }
-      my_casedn_str(files_charset_info, new_name);
-    }
+    strcpy(new_name_buff, new_name);
+    strcpy(new_alias_buff, new_name);
+    new_alias= new_alias_buff;
+
+    my_casedn_str(files_charset_info, new_name_buff);
+    new_alias= new_name;			// Create lower case table name
+    my_casedn_str(files_charset_info, new_name);
+
     if (new_db == db &&
 	!my_strcasecmp(table_alias_charset, new_name_buff, table_name))
     {
@@ -3840,7 +3808,7 @@
         }
 
         build_table_filename(new_name_buff, sizeof(new_name_buff),
-                             new_db, new_name_buff, "", 0);
+                             new_db, new_name_buff, false);
         if (table_proto_exists(new_name_buff)==EEXIST)
 	{
 	  /* Table will be closed by Session::executeCommand() */
@@ -3852,7 +3820,7 @@
   }
   else
   {
-    new_alias= (lower_case_table_names == 2) ? alias : table_name;
+    new_alias= table_name;
     new_name= table_name;
   }
 
@@ -3961,7 +3929,7 @@
       else
       {
 	*fn_ext(new_name)=0;
-	if (mysql_rename_table(old_db_type,db,table_name,new_db,new_alias, 0))
+	if (mysql_rename_table(old_db_type, db, table_name, new_db, new_alias, 0))
 	  error= -1;
         else if (0)
       {
@@ -4022,8 +3990,7 @@
   snprintf(tmp_name, sizeof(tmp_name), "%s-%lx_%"PRIx64, TMP_FILE_PREFIX,
            (unsigned long)current_pid, session->thread_id);
   /* Safety fix for innodb */
-  if (lower_case_table_names)
-    my_casedn_str(files_charset_info, tmp_name);
+  my_casedn_str(files_charset_info, tmp_name);
 
 
   /* Create a temporary table with the new format */
@@ -4040,7 +4007,9 @@
     TableList tbl;
     memset(&tbl, 0, sizeof(tbl));
     tbl.db= new_db;
-    tbl.table_name= tbl.alias= tmp_name;
+    tbl.alias= tmp_name;
+    tbl.table_name= tmp_name;
+
     /* Table is in session->temporary_tables */
     new_table= open_table(session, &tbl, (bool*) 0, DRIZZLE_LOCK_IGNORE_FLUSH);
   }
@@ -4048,8 +4017,7 @@
   {
     char tmp_path[FN_REFLEN];
     /* table is a normal table: Create temporary table in same directory */
-    build_table_filename(tmp_path, sizeof(tmp_path), new_db, tmp_name, "",
-                         FN_IS_TMP);
+    build_table_filename(tmp_path, sizeof(tmp_path), new_db, tmp_name, true);
     /* Open our intermediate table */
     new_table=open_temporary_table(session, tmp_path, new_db, tmp_name, 0, OTM_OPEN);
   }
@@ -4145,8 +4113,7 @@
   session->set_proc_info("rename result table");
   snprintf(old_name, sizeof(old_name), "%s2-%lx-%"PRIx64, TMP_FILE_PREFIX,
            (unsigned long)current_pid, session->thread_id);
-  if (lower_case_table_names)
-    my_casedn_str(files_charset_info, old_name);
+  my_casedn_str(files_charset_info, old_name);
 
   wait_while_table_is_used(session, table, HA_EXTRA_PREPARE_FOR_RENAME);
   close_data_files_and_morph_locks(session, db, table_name);
@@ -4178,9 +4145,9 @@
   {
     /* Try to get everything back. */
     error=1;
-    quick_rm_table(new_db_type,new_db,new_alias, 0);
+    quick_rm_table(new_db_type, new_db, new_alias, 0);
     quick_rm_table(new_db_type, new_db, tmp_name, FN_IS_TMP);
-    mysql_rename_table(old_db_type, db, old_name, db, alias,
+    mysql_rename_table(old_db_type, db, old_name, db, table_name,
                        FN_FROM_IS_TMP);
   }
 
@@ -4215,7 +4182,7 @@
     */
     char table_path[FN_REFLEN];
     Table *t_table;
-    build_table_filename(table_path, sizeof(table_path), new_db, table_name, "", 0);
+    build_table_filename(table_path, sizeof(table_path), new_db, table_name, false);
     t_table= open_temporary_table(session, table_path, new_db, tmp_name, false, OTM_OPEN);
     if (t_table)
     {

=== modified file 'drizzled/sql_table.h'
--- drizzled/sql_table.h	2009-03-24 17:44:41 +0000
+++ drizzled/sql_table.h	2009-05-27 23:03:42 +0000
@@ -36,8 +36,8 @@
                     bool drop_temporary);
 int mysql_rm_table_part2(Session *session, TableList *tables, bool if_exists,
                          bool drop_temporary, bool log_query);
-bool quick_rm_table(StorageEngine *base,const char *db,
-                    const char *table_name, uint32_t flags);
+bool quick_rm_table(StorageEngine *, const char *db,
+                    const char *table_name, bool is_tmp);
 void close_cached_table(Session *session, Table *table);
 
 void wait_while_table_is_used(Session *session, Table *table,

=== modified file 'drizzled/sql_union.cc'
--- drizzled/sql_union.cc	2009-05-19 05:29:40 +0000
+++ drizzled/sql_union.cc	2009-05-27 19:47:42 +0000
@@ -357,7 +357,8 @@
       goto err;
     memset(&result_table_list, 0, sizeof(result_table_list));
     result_table_list.db= (char*) "";
-    result_table_list.table_name= result_table_list.alias= (char*) "union";
+    result_table_list.alias= "union";
+    result_table_list.table_name= (char *) "union";
     result_table_list.table= table= union_result->table;
 
     session_arg->lex->current_select= lex_select_save;

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2009-05-26 02:54:31 +0000
+++ drizzled/table.cc	2009-05-27 23:03:42 +0000
@@ -134,7 +134,7 @@
 
   path_length= build_table_filename(path, sizeof(path) - 1,
                                     table_list->db,
-                                    table_list->table_name, "", 0);
+                                    table_list->table_name, false);
   init_sql_alloc(&mem_root, TABLE_ALLOC_BLOCK_SIZE, 0);
   if (multi_alloc_root(&mem_root,
                        &share, sizeof(*share),
@@ -2096,9 +2096,6 @@
     check_db_name()
     org_name		Name of database and length
 
-  NOTES
-    If lower_case_table_names is set then database is converted to lower case
-
   RETURN
     0	ok
     1   error
@@ -2112,7 +2109,7 @@
   if (!name_length || name_length > NAME_LEN || name[name_length - 1] == ' ')
     return 1;
 
-  if (lower_case_table_names && name != any_db)
+  if (name != any_db)
     my_casedn_str(files_charset_info, name);
 
   return check_identifier_name(org_name);
@@ -3180,7 +3177,7 @@
 create_tmp_table(Session *session,Tmp_Table_Param *param,List<Item> &fields,
 		 order_st *group, bool distinct, bool save_sum_fields,
 		 uint64_t select_options, ha_rows rows_limit,
-		 char *table_alias)
+		 const char *table_alias)
 {
   MEM_ROOT *mem_root_save, own_root;
   Table *table;

=== modified file 'drizzled/table_list.h'
--- drizzled/table_list.h	2009-05-22 22:09:30 +0000
+++ drizzled/table_list.h	2009-05-27 19:47:42 +0000
@@ -145,7 +145,7 @@
   TableList **prev_global;
 
   char		*db;
-  char		*alias;
+  const char		*alias;
   char		*table_name;
   char		*schema_table_name;
   char    *option;                /* Used by cache index  */

=== modified file 'drizzled/table_proto_write.cc'
--- drizzled/table_proto_write.cc	2009-05-19 06:17:12 +0000
+++ drizzled/table_proto_write.cc	2009-05-27 23:03:42 +0000
@@ -574,7 +574,7 @@
 
   int error= access(proto_path.c_str(), F_OK);
 
-  if(error==0)
+  if (error == 0)
     return EEXIST;
   else
     return errno;

=== removed file 'mysys/my_fopen.cc'
--- mysys/my_fopen.cc	2009-05-23 16:15:00 +0000
+++ mysys/my_fopen.cc	1970-01-01 00:00:00 +0000
@@ -1,140 +0,0 @@
-/* Copyright (C) 2000 MySQL AB
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
-#include "mysys/mysys_priv.h"
-#include "my_static.h"
-#include "mysys/mysys_err.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <errno.h>
-#include <string.h>
-
-static void make_ftype(char * to,int flag);
-
-/*
-  Open a file as stream
-
-  SYNOPSIS
-    my_fopen()
-    FileName	Path-name of file
-    Flags	Read | write | append | trunc (like for open())
-    MyFlags	Flags for handling errors
-
-  RETURN
-    0	Error
-    #	File handler
-*/
-
-FILE *my_fopen(const char *filename, int flags, myf MyFlags)
-{
-  FILE *fd;
-  char type[5];
-  /*
-    if we are not creating, then we need to use my_access to make sure
-    the file exists since Windows doesn't handle files like "com1.sym"
-    very  well
-  */
-  {
-    make_ftype(type,flags);
-    fd = fopen(filename, type);
-  }
-
-  if (fd != NULL)
-  {
-    my_stream_opened++;
-    return fd;				/* safeguard */
-  }
-  else
-    my_errno=errno;
-  if (MyFlags & (MY_FFNF | MY_FAE | MY_WME))
-    my_error((flags & O_RDONLY) || (flags == O_RDONLY ) ? EE_FILENOTFOUND :
-	     EE_CANTCREATEFILE,
-	     MYF(ME_BELL+ME_WAITTANG), filename, my_errno);
-  return NULL;
-} /* my_fopen */
-
-
-	/* Close a stream */
-
-int my_fclose(FILE *fd, myf MyFlags)
-{
-  int err,file;
-
-  file= fileno(fd);
-  if ((err = fclose(fd)) < 0)
-  {
-    my_errno=errno;
-    if (MyFlags & (MY_FAE | MY_WME))
-      my_error(EE_BADCLOSE, MYF(ME_BELL+ME_WAITTANG),
-	       my_filename(file),errno);
-  }
-  else
-    my_stream_opened--;
-
-  return(err);
-} /* my_fclose */
-
-
-
-/*
-  Make a fopen() typestring from a open() type bitmap
-
-  SYNOPSIS
-    make_ftype()
-    to		String for fopen() is stored here
-    flag	Flag used by open()
-
-  IMPLEMENTATION
-    This routine attempts to find the best possible match
-    between  a numeric option and a string option that could be
-    fed to fopen.  There is not a 1 to 1 mapping between the two.
-
-  NOTE
-    On Unix, O_RDONLY is usually 0
-
-  MAPPING
-    r  == O_RDONLY
-    w  == O_WRONLY|O_TRUNC|O_CREAT
-    a  == O_WRONLY|O_APPEND|O_CREAT
-    r+ == O_RDWR
-    w+ == O_RDWR|O_TRUNC|O_CREAT
-    a+ == O_RDWR|O_APPEND|O_CREAT
-*/
-
-static void make_ftype(register char * to, register int flag)
-{
-  /* check some possible invalid combinations */
-  assert((flag & (O_TRUNC | O_APPEND)) != (O_TRUNC | O_APPEND));
-  assert((flag & (O_WRONLY | O_RDWR)) != (O_WRONLY | O_RDWR));
-
-  if ((flag & (O_RDONLY|O_WRONLY)) == O_WRONLY)
-    *to++= (flag & O_APPEND) ? 'a' : 'w';
-  else if (flag & O_RDWR)
-  {
-    /* Add '+' after theese */
-    if (flag & (O_TRUNC | O_CREAT))
-      *to++= 'w';
-    else if (flag & O_APPEND)
-      *to++= 'a';
-    else
-      *to++= 'r';
-    *to++= '+';
-  }
-  else
-    *to++= 'r';
-
-  *to='\0';
-} /* make_ftype */

=== modified file 'mysys/my_static.h'
--- mysys/my_static.h	2009-05-23 16:15:00 +0000
+++ mysys/my_static.h	2009-05-26 20:45:27 +0000
@@ -58,8 +58,6 @@
 extern volatile int _my_signals;
 extern struct st_remember _my_sig_remember[MAX_SIGNALS];
 
-extern const char *soundex_map;
-
 extern unsigned char	*sf_min_adress,*sf_max_adress;
 extern uint	sf_malloc_count;
 extern struct st_irem *sf_malloc_root;

=== modified file 'mysys/my_sys.h'
--- mysys/my_sys.h	2009-05-26 02:54:31 +0000
+++ mysys/my_sys.h	2009-05-26 20:45:27 +0000
@@ -377,8 +377,6 @@
 extern bool array_append_string_unique(const char *str,
                                           const char **array, size_t size);
 extern void get_date(char * to,int timeflag,time_t use_time);
-extern void soundex(CHARSET_INFO *, char * out_pntr, char * in_pntr,
-                    bool remove_garbage);
 extern int init_record_cache(RECORD_CACHE *info,size_t cachesize,File file,
 			     size_t reclength,enum cache_type type,
 			     bool use_async_io);
@@ -448,7 +446,6 @@
 extern ha_checksum my_checksum(ha_checksum crc, const unsigned char *mem,
                                size_t count);
 extern void my_sleep(uint32_t m_seconds);
-extern uint64_t my_set_max_open_files(uint64_t files);
 void my_free_open_file_info(void);
 
 extern uint64_t my_getsystime(void);

=== modified file 'plugin/csv/ha_tina.cc'
--- plugin/csv/ha_tina.cc	2009-05-08 20:20:28 +0000
+++ plugin/csv/ha_tina.cc	2009-05-26 20:57:34 +0000
@@ -109,8 +109,7 @@
 {
 public:
   Tina(const string& name_arg)
-   : StorageEngine(name_arg, HTON_CAN_RECREATE | HTON_SUPPORT_LOG_TABLES |
-                             HTON_NO_PARTITION) {}
+   : StorageEngine(name_arg, HTON_CAN_RECREATE) {}
   virtual handler *create(TableShare *table,
                           MEM_ROOT *mem_root)
   {

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2009-05-19 07:09:04 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2009-05-27 21:11:30 +0000
@@ -5594,11 +5594,7 @@
 
 	trx = innobase_trx_allocate(session);
 
-	if (lower_case_table_names) {
-		srv_lower_case_table_names = TRUE;
-	} else {
-		srv_lower_case_table_names = FALSE;
-	}
+        srv_lower_case_table_names = TRUE;
 
 	strcpy(name2, name);
 
@@ -5990,11 +5986,7 @@
 
 	trx = innobase_trx_allocate(session);
 
-	if (lower_case_table_names) {
-		srv_lower_case_table_names = TRUE;
-	} else {
-		srv_lower_case_table_names = FALSE;
-	}
+        srv_lower_case_table_names = TRUE;
 
 	name_len = strlen(name);
 
@@ -6119,11 +6111,7 @@
 	char*	norm_to;
 	char*	norm_from;
 
-	if (lower_case_table_names) {
-		srv_lower_case_table_names = TRUE;
-	} else {
-		srv_lower_case_table_names = FALSE;
-	}
+        srv_lower_case_table_names = TRUE;
 
 	// Magic number 64 arbitrary
 	norm_to = (char*) malloc(strlen(to) + 64);

=== modified file 'plugin/myisam/ha_myisam.cc'
--- plugin/myisam/ha_myisam.cc	2009-05-09 22:13:47 +0000
+++ plugin/myisam/ha_myisam.cc	2009-05-26 20:57:34 +0000
@@ -64,7 +64,7 @@
 {
 public:
   MyisamEngine(string name_arg)
-   : StorageEngine(name_arg, HTON_CAN_RECREATE | HTON_SUPPORT_LOG_TABLES) {}
+   : StorageEngine(name_arg, HTON_CAN_RECREATE) {}
 
   virtual handler *create(TableShare *table,
                           MEM_ROOT *mem_root)

